<?php
/**
* Llibreria de conexio a Base de Dades en Mysql
*
* @author   Javi Filella    <txusko@gmail.com>
*
* @created 2011-04
* @version 1.0
*/

interface Db {
	function __construct($server = "localhost", $user = "root", $password = "", $database = "test", $persistent = false);
	function connect_DB();
	function close_DB();
	function select($sql);
	function insert($sql);
	function update($sql);
	function delete($sql);
	function checkConnection($string="",$sql="");
}

class MysqlDb implements Db {

    /**
    * Direcció del Servidor.
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @private
    * @type     string
    **/
    var $server;

    /**
    * Nombre del usuario.
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @private
    * @type     string
    **/
    var $user;

    /**
    * Password de acceso.
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @private
    * @type     string
    **/
    var $pass;

    /**
    * Nombre de la Base de Datos
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @private
    * @type     string
    **/
    var $dataBase;

    /**
    * Variable que contendra el handler de la conexió.
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @private
    * @type     string
    **/
    var $connection;

    /**
    * Constructor mysqlDB()
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @param    $server     Direcció del servidor
    * @param    $user       Usuario de acceso
    * @param    $password   Password de acceso
    * @param    $database   Base de datos
    *
    * @returns  void
    * @public
    */
    function __construct($server = "localhost", $user = "root", $password = "", $database = "test", $persistent = false) {
        $this->server   = $server;
		$this->user     = $user;
        $this->pass     = $password;
        $this->database = $database;
        $this->persistent = $persistent;
        //Conectem
        $this->connect_DB();
    }

    /**
    * Establece la conexió a la base de datos
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @returns  void
    * @public
    */
    function connect_DB() {
        $user 		= $this->user;
        $pass 		= $this->pass;
        $server 	= $this->server;
        $dataBase 	= $this->database;

		try {
        	if ($this->persistent) {
            	$link=mysql_pconnect($server,$user,$pass);
       		} else {
            	$link=mysql_connect($server,$user,$pass,1);
            }
        	if(mysql_select_db($dataBase,$link)) {
        		$this->connection = $link;
        	}
    	} catch (Exception $e) {
    		printf("Message = %s\n",$e->__toString());
		}
    }

    /**
    * Cierra la conexió a la base de datos
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @returns  void
    * @public
    */
    function close_DB() {
        if ($this->connection) {
            mysql_close($this->connection);
        }
    }

    /**
    * Inserció a Base de dades
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @param    $sql   Consulta de insercion
    *
    * @returns  int		Id de l'ultim registre insertat
    * @public
    */
    function insert($sql) {
        if($this->checkConnection("insert", $sql)) {
	        $results = mysql_query($sql,$this->connection);
    	    if($results) {
	            return mysql_insert_id();
			}
		}
        return false;
    }

    /**
    * Selecció
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @param    $sql   Consulta de selecció
    *
    * @returns  array	Array amb els resultats
    * @public
    */
    function select($sql) {
        if($this->checkConnection("select", $sql)) {
        	$results = mysql_query($sql,$this->connection);

        	if(!$results || empty($results)) {
        		return false;
        	}
            	
        	$c = 0;
        	$data = array();
        	while($row = mysql_fetch_array($results,MYSQL_ASSOC)) {
            	$data[$c] = $row;
            	$c++;
        	}
        	mysql_free_result($results);

        	if(count($data)) {
            	return $data;
        	}
        }
        return false;
    }

    /**
    * Actualizació
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @param    $sql   Consulta de actualizació
    *
    * @returns  bool	Indicant el exit o el fracas de la operació
    * @public
    */
    public function update($sql) {
        if($this->checkConnection("update", $sql)) {
        	return $this->exec($sql);
        }
    }

    /**
    * Eliminació
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @param    $sql   Consulta de eliminació
    *
    * @returns  bool	Indicant el exit o el fracas de la operació
    * @public
    */
    public function delete($sql) {
        if($this->checkConnection("delete", $sql)) {
        	return $this->exec($sql);
        }
    }

    /**
    * Consulta de ejecució: ejecuta qualquier consulta: update,
    * delete, create, flush privileges ...
    *
    * @author   Javi Filella    <txusko@gmail.com>
    * @created 2011-04
    *
    * @param    $sql   Consulta de ejecució
    *
    * @returns  bool
    * @public
    */
    public function exec($sql) {
        $results = mysql_query($sql,$this->connection);
        if($results) {
            return $results;
        }
        return false;
    }

    public function checkConnection($string = "", $sql = "") {
    	if(empty($this->connection)) {
        	return false;
		}
		
        if(empty($sql)) { 
        	return false; 
        }
        if($string && !eregi("^$string",$sql)) {
            return false;
        }
       
        return true;
    }
}

?>